pub struct Command { /* private fields */ }Expand description
A graphics protocol command ready for serialization
Implementations
Sourceimpl Command
impl Command
Sourcepub fn builder() -> CommandBuilder
pub fn builder() -> CommandBuilder
Create a new command builder
Sourcepub fn serialize(&self, data: &[u8]) -> Result<String>
pub fn serialize(&self, data: &[u8]) -> Result<String>
Serialize the command to an escape sequence string
Sourcepub fn serialize_chunked(&self, data: &[u8]) -> Result<ChunkedSerializer>
pub fn serialize_chunked(&self, data: &[u8]) -> Result<ChunkedSerializer>
Serialize command in chunks for large data Returns an iterator of escape sequences
Sourcepub fn serialize_with_path(&self) -> Result<String>
pub fn serialize_with_path(&self) -> Result<String>
Serialize a command with a path (for file/shared memory transmission)
Sourceimpl Command
Convenience functions for common operations
impl Command
Convenience functions for common operations
Sourcepub fn query_support() -> Self
pub fn query_support() -> Self
Create a command to query protocol support
Sourcepub fn transmit_png(data: &[u8]) -> Result<Vec<String>>
pub fn transmit_png(data: &[u8]) -> Result<Vec<String>>
Create a command to transmit and display a PNG image
Sourcepub fn transmit_rgba(
data: &[u8],
width: u32,
height: u32,
) -> Result<Vec<String>>
pub fn transmit_rgba( data: &[u8], width: u32, height: u32, ) -> Result<Vec<String>>
Create a command to transmit and display raw RGBA data
Sourcepub fn transmit_rgb(data: &[u8], width: u32, height: u32) -> Result<Vec<String>>
pub fn transmit_rgb(data: &[u8], width: u32, height: u32) -> Result<Vec<String>>
Create a command to transmit and display raw RGB data
Sourcepub fn delete_all() -> Self
pub fn delete_all() -> Self
Create a command to delete all visible placements
Sourcepub fn delete_by_id(image_id: u32) -> Self
pub fn delete_by_id(image_id: u32) -> Self
Create a command to delete an image by ID